@@ -4,8 +4,9 @@
 #' @description Let the user copy data from Excel or text file then paste it into a text area to import it.
 #'
 #' @inheritParams import-globalenv
+#' @param name_field Show or not a field to add a name to data (that is returned server-side).
 #'
-#' @eval doc_return_import()
+#' @template module-import
 #'
 #' @export
 #'
@@ -15,7 +16,7 @@
 #' @importFrom htmltools tags tagAppendAttributes
 #'
 #' @example examples/from-copypaste.R
-import_copypaste_ui <- function(id, title = TRUE) {
+import_copypaste_ui <- function(id, title = TRUE, name_field = TRUE) {
 
   ns <- NS(id)
 
@@ -40,12 +41,14 @@ import_copypaste_ui <- function(id, title = TRUE) {
       ),
       class = "shiny-input-container-inline"
     ),
-    textInput(
-      inputId = ns("name"),
-      label = NULL,
-      placeholder = i18n("Add a label to data"),
-      width = "100%"
-    ),
+   if (isTRUE(name_field)) {
+     textInput(
+       inputId = ns("name"),
+       label = NULL,
+       placeholder = i18n("Add a label to data"),
+       width = "100%"
+     )
+   },
     tags$div(
       id = ns("import-placeholder"),
       alert(
@@ -65,6 +68,7 @@ import_copypaste_ui <- function(id, title = TRUE) {
 
 
 #' @inheritParams import_globalenv_server
+#' @param fread_args `list` of additional arguments to pass to [data.table::fread()] when reading data.
 #'
 #' @export
 #'
@@ -77,9 +81,11 @@ import_copypaste_ui <- function(id, title = TRUE) {
 #' @rdname import-copypaste
 import_copypaste_server <- function(id,
                                     btn_show_data = TRUE,
+                                    show_data_in = c("popup", "modal"),
                                     trigger_return = c("button", "change"),
                                     return_class = c("data.frame", "data.table", "tbl_df"),
-                                    reset = reactive(NULL)) {
+                                    reset = reactive(NULL),
+                                    fread_args = list()) {
 
   trigger_return <- match.arg(trigger_return)
 
@@ -103,11 +109,12 @@ import_copypaste_server <- function(id,
 
     observeEvent(input$data_pasted, {
       req(input$data_pasted)
-      imported <- try(data.table::fread(text = input$data_pasted), silent = TRUE)
+      fread_args$tex <- input$data_pasted
+      imported <- try(rlang::exec(data.table::fread, !!!fread_args), silent = TRUE)
 
       if (inherits(imported, "try-error") || NROW(imported) < 1) {
         toggle_widget(inputId = "confirm", enable = FALSE)
-        insert_error()
+        insert_error(mssg = i18n(attr(imported, "condition")$message))
         temporary_rv$status <- "error"
         temporary_rv$data <- NULL
         temporary_rv$name <- NULL
@@ -136,7 +143,7 @@ import_copypaste_server <- function(id,
     })
 
     observeEvent(input$see_data, {
-      show_data(temporary_rv$data, title = i18n("Imported data"))
+      show_data(temporary_rv$data, title = i18n("Imported data"), type = show_data_in)
     })
 
     observeEvent(input$confirm, {
