@@ -5,7 +5,7 @@
 #'
 #' @inheritParams import-globalenv
 #'
-#' @eval doc_return_import()
+#' @template module-import
 #'
 #' @export
 #' @name import-googlesheets
@@ -79,6 +79,7 @@ import_googlesheets_ui <- function(id, title = TRUE) {
 #' @rdname import-googlesheets
 import_googlesheets_server <- function(id,
                                        btn_show_data = TRUE,
+                                       show_data_in = c("popup", "modal"),
                                        trigger_return = c("button", "change"),
                                        return_class = c("data.frame", "data.table", "tbl_df"),
                                        reset = reactive(NULL)) {
@@ -114,7 +115,7 @@ import_googlesheets_server <- function(id,
       imported <- try(read_gsheet(input$link), silent = TRUE)
       if (inherits(imported, "try-error") || NROW(imported) < 1) {
         toggle_widget(inputId = "confirm", enable = FALSE)
-        insert_error()
+        insert_error(mssg = i18n(attr(imported, "condition")$message))
         temporary_rv$status <- "error"
         temporary_rv$data <- NULL
       } else {
@@ -134,7 +135,7 @@ import_googlesheets_server <- function(id,
     }, ignoreInit = TRUE)
 
     observeEvent(input$see_data, {
-      show_data(temporary_rv$data, title = i18n("Imported data"))
+      show_data(temporary_rv$data, title = i18n("Imported data"), type = show_data_in)
     })
 
     observeEvent(input$confirm, {
