@@ -11,10 +11,6 @@ nullOrEmpty <- function(x) {
   is.null(x) || length(x) == 0 || x == ""
 }
 
-`%||%` <- function(x, y) {
-  if (!is.null(x)) x else y
-}
-
 #' @importFrom data.table .SD
 dropListColumns <- function(x) {
   type_col <- vapply(
@@ -30,6 +26,7 @@ dropListColumns <- function(x) {
   }
 }
 
+
 #' Search for object with specific class in an environment
 #'
 #' @param what a class to look for
